@@ -74,9 +74,9 @@
 #' HARQ <- with(RV2, lm(RV ~ RV_lag + I(RV_lag * RQ_lag_sqrt) + RV_week + RV_month))
 #' 
 #' #Casas et al. (2018) TVHARQ model
-#' tvHARQ <- with(RV2, tvLM (RV ~ RV_lag + RV_week + RV_month, z = RQ_lag_sqrt, 
+#' TVHARQ <- with(RV2, tvLM (RV ~ RV_lag + RV_week + RV_month, z = RQ_lag_sqrt, 
 #'                          bw = 0.0061))
-#' boxplot(data.frame(tvHARQ = tvHARQ$coefficients[,2] * RV2$RV_lag,
+#' boxplot(data.frame(TVHARQ = TVHARQ$coefficients[,2] * RV2$RV_lag,
 #'                    HARQ = (HARQ$coef[2] + HARQ$coef[3] * RV2$RQ_lag_sqrt)*RV2$RV_lag),
 #'                    main = expression (RV[t-1]), outline = FALSE)
 #'                  
@@ -121,7 +121,8 @@ tvLM<-function (formula, z = NULL, ez = NULL, data, bw = NULL, cv.block = 0, est
                       singular.ok = singular.ok)
   }
   nvar <- ncol(x)
-  xnames<-colnames(x)
+  xnames <- colnames(x)
+  yname <- attr(mt, "variables")[[2]]
   if(is.null(xnames))
     xnames <- paste("X", 1:nvar, collate="&", sep="")
   coefficients <-results$coefficients
